aboutsummaryrefslogtreecommitdiffstats
path: root/models
diff options
context:
space:
mode:
Diffstat (limited to 'models')
-rw-r--r--models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdate.java (renamed from models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdate.java)12
-rw-r--r--models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantMessageType.java4
-rw-r--r--models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdateTest.java (renamed from models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdateTest.java)8
3 files changed, 12 insertions, 12 deletions
diff --git a/models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdateTest.java b/models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdateTest.java
index 5d87095ba..ac164e32b 100644
--- a/models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdateTest.java
+++ b/models/src/test/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdateTest.java
@@ -35,12 +35,12 @@ import org.onap.policy.models.tosca.authorative.concepts.ToscaServiceTemplate;
/**
* Test the copy constructor.
*/
-class ParticipantControlLoopUpdateTest {
+class ControlLoopUpdateTest {
@Test
void testCopyConstructor() {
- assertThatThrownBy(() -> new ParticipantControlLoopUpdate(null)).isInstanceOf(NullPointerException.class);
+ assertThatThrownBy(() -> new ControlLoopUpdate(null)).isInstanceOf(NullPointerException.class);
- ParticipantControlLoopUpdate orig = new ParticipantControlLoopUpdate();
+ ControlLoopUpdate orig = new ControlLoopUpdate();
// verify with all values
ToscaConceptIdentifier id = new ToscaConceptIdentifier();
id.setName("id");
@@ -60,7 +60,7 @@ class ParticipantControlLoopUpdateTest {
orig.setControlLoopDefinition(toscaServiceTemplate);
orig.setControlLoop(controlLoop);
- ParticipantControlLoopUpdate other = new ParticipantControlLoopUpdate(orig);
+ ControlLoopUpdate other = new ControlLoopUpdate(orig);
assertEquals(removeVariableFields(orig.toString()), removeVariableFields(other.toString()));
diff --git a/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdate.java b/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdate.java
index ed729a64b..f73adf928 100644
--- a/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantControlLoopUpdate.java
+++ b/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ControlLoopUpdate.java
@@ -27,14 +27,14 @@ import org.onap.policy.clamp.controlloop.models.controlloop.concepts.ControlLoop
import org.onap.policy.models.tosca.authorative.concepts.ToscaServiceTemplate;
/**
* Class to represent the PARTICIPANT_CONTROL_LOOP_UPDATE message that the control loop runtime sends to a participant.
* When a participant receives this message, it creates the control loop elements contained in the message and sets them
* to state PASSIVE. subsequent PARTICIPANT_CONTROL_LOOP_STATE_CHANGE messages are used to activate the control loops.
*/
@Getter
@Setter
@ToString(callSuper = true)
-public class ParticipantControlLoopUpdate extends ParticipantMessage {
+public class ControlLoopUpdate extends ParticipantMessage {
// The control loop
private ControlLoop controlLoop;
@@ -42,11 +42,11 @@ public class ParticipantControlLoopUpdate extends ParticipantMessage {
private ToscaServiceTemplate controlLoopDefinition;
/**
* Constructor for instantiating ParticipantControlLoopUpdate class with message name.
*
*/
- public ParticipantControlLoopUpdate() {
- super(ParticipantMessageType.PARTICIPANT_CONTROL_LOOP_UPDATE);
+ public ControlLoopUpdate() {
+ super(ParticipantMessageType.CONTROL_LOOP_UPDATE);
}
/**
@@ -54,7 +54,7 @@ public class ParticipantControlLoopUpdate extends ParticipantMessage {
*
* @param source source from which to copy
*/
- public ParticipantControlLoopUpdate(ParticipantControlLoopUpdate source) {
+ public ControlLoopUpdate(ControlLoopUpdate source) {
super(source);
this.controlLoop = new ControlLoop(source.controlLoop);
@@ -27,14 +27,14 @@ import org.onap.policy.clamp.controlloop.models.controlloop.concepts.ControlLoop
import org.onap.policy.models.tosca.authorative.concepts.ToscaServiceTemplate;
/**
- * Class to represent the PARTICIPANT_CONTROL_LOOP_UPDATE message that the control loop runtime sends to a participant.
+ * Class to represent the CONTROL_LOOP_UPDATE message that the control loop runtime sends to a participant.
* When a participant receives this message, it creates the control loop elements contained in the message and sets them
* to state PASSIVE. subsequent PARTICIPANT_CONTROL_LOOP_STATE_CHANGE messages are used to activate the control loops.
@@ -42,11 +42,11 @@ public class ParticipantControlLoopUpdate extends ParticipantMessage {
private ToscaServiceTemplate controlLoopDefinition;
/**
- * Constructor for instantiating ParticipantControlLoopUpdate class with message name.
+ * Constructor for instantiating ControlLoopUpdate class with message name.
*
*/
diff --git a/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantMessageType.java b/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantMessageType.java
index 94d484620..22f5a1793 100644
--- a/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantMessageType.java
+++ b/models/src/main/java/org/onap/policy/clamp/controlloop/models/messages/dmaap/participant/ParticipantMessageType.java
@@ -38,9 +38,9 @@ public enum ParticipantMessageType {
/**
* Used by controlloop runtime to update the controlloops running on participants, triggers a
* PARTICIPANT_STATUS message with the result of the PARTICIPANT_CONTROL_LOOP_UPDATE operation.
*/
- PARTICIPANT_CONTROL_LOOP_UPDATE,
+ CONTROL_LOOP_UPDATE,
/**
* Used by controlloop runtime to change the state of controlloops in participants, triggers a
@@ -38,9 +38,9 @@ public enum ParticipantMessageType {
/**
* Used by controlloop runtime to update the controlloops running on participants, triggers a
- * PARTICIPANT_STATUS message with the result of the PARTICIPANT_CONTROL_LOOP_UPDATE operation.
+ * PARTICIPANT_STATUS message with the result of the CONTROL_LOOP_UPDATE operation.
*/